;-------------------------------------------------------------
;+
;
; @file_comments
; return right subportion from a string
;
; @categories
; String
; 
; @param S {in}{required}
; the string to be searched
;
; @param LASTN {in}{required}{default=1}
; the number of characters to be returned.
; If NLAST is the strlen(STRING), the complete string
; is returned.
;
; @returns
; The portion of LASTN characters of S counted from the back.
;
; @examples
; if (strright(path) ne '/') then path = path + '/'
;
; @history
;        mgs, 19 Nov 1997: VERSION 1.00
;
; @version
; $Id$
;
;-
; Copyright (C) 1997, Martin Schultz, Harvard University
; This software is provided as is without any warranty
; whatsoever. It may be freely used, copied or distributed
; for non-commercial purposes. This copyright notice must be
; kept with any copy of this software. If this software shall
; be used commercially or sold as part of a larger package,
; please contact the author to arrange payment.
; Bugs and comments should be directed to mgs@io.harvard.edu
; with subject "IDL routine strright"
;-------------------------------------------------------------


function strright,s,lastn
;
  compile_opt idl2, strictarrsubs
;
 
    on_error,2   ; return to caller
 
    if (n_elements(s) le 0) then return,-1L
 
    l = strlen(s)
 
    if (n_elements(lastn) le 0) then lastn = 1
    if lastn gt l then lastn = l
 
    result = strmid(s,l-lastn,l)
 
    return,result
end
